Welcome to Printen's documentation!
===================================

This documentation below will quickly get you up to
speed on using Printen to integrate Elasticsearch
into your Python project.

Contents:
---------
* [Overview](readme.md)
* [Example Usage](usage.md)
* [API Reference](api.md)
